@@ -26,6 +26,7 @@
 
 // Qt
 #include <QString>
+
 class QLabel;
 #include <qlist.h>
 #include <QVBoxLayout>
@@ -39,7 +40,6 @@ class KAction;
 #include <kxmlguiwindow.h>
 
 // KMix
-class GUIProfile;
 class KMixPrefDlg;
 class KMixDockWidget;
 class KMixerWidget;
@@ -59,9 +59,6 @@ KMixWindow : public KXmlGuiWindow
    KMixWindow(bool invisible);
    ~KMixWindow();
 
-   bool updateDocking();
-   Qt::Orientation toplevelOrientation() { return m_toplevelOrientation; }
-
   private:
    void saveBaseConfig();
    void saveViewConfig();
@@ -82,6 +79,7 @@ KMixWindow : public KXmlGuiWindow
    virtual bool queryClose();
 
   public slots:
+   void controlsChange(int changeType);
    void quit();
    void showSettings();
    void showHelp();
@@ -91,13 +89,11 @@ KMixWindow : public KXmlGuiWindow
    void loadVolumes(QString postfix);
    void saveVolumes();
    void saveVolumes(QString postfix);
+   void saveConfig();
    virtual void applyPrefs( KMixPrefDlg *prefDlg );
    void recreateGUI(bool saveView);
    void recreateGUI(bool saveConfig, const QString& mixerId, bool forceNewTab);
    void recreateGUIwithSavingView();
-   void recreateGUIwithoutSavingView();
-   void recreateDockWidget();
-   void redrawMixer( const QString& mixer_ID );
    void newMixerShown(int tabIndex);
 
     private:
@@ -109,17 +105,21 @@ KMixWindow : public KXmlGuiWindow
    KAccel *m_keyAccel;
    KAction* _actionShowMenubar;
 
+   // move many of the following to a central static configuration object
+   // (they come from the KMix config file, so they are really "static".
    bool m_showDockWidget;
-   bool m_volumeWidget;
-   bool m_showTicks;
-   bool m_showLabels;
+   bool trayVolumePopupEnabled;
+   
+private:
    bool m_onLogin;
+   bool allowAutostart;
    bool m_beepOnVolumeChange;
    bool m_startVisible;
    bool m_visibilityUpdateAllowed;
    bool m_multiDriverMode;         // Not officially supported.
    bool m_autouseMultimediaKeys;   // Due to message freeze, not in config dialog in KDE4.4
-   Qt::Orientation m_toplevelOrientation;
+
+   bool forceNotifierRebuild;
 
    KTabWidget *m_wsMixers;
 
@@ -137,14 +137,17 @@ KMixWindow : public KXmlGuiWindow
 
    OSDWidget* osdWidget;
 
-   bool addMixerWidget(const QString& mixer_ID, GUIProfile *guiprof, int insertPosition);
+   bool addMixerWidget(const QString& mixer_ID, QString guiprofId, int insertPosition);
    void setInitialSize();
 
     private:
-   static QString getKmixctrlRcFilename(QString postfix);
+    static QString getKmixctrlRcFilename(QString postfix);
+	bool profileExists(QString guiProfileId);
+	bool updateDocking();
+	void removeDock();
+	void updateTabsClosable();
 
   private slots:
-   void saveConfig();
    void slotHWInfo();
    void slotKdeAudioSetupExec();
    void slotConfigureCurrentView();
@@ -168,7 +171,6 @@ KMixWindow : public KXmlGuiWindow
    void saveVolumes2() { saveVolumes(QString("2")); }
    void saveVolumes3() { saveVolumes(QString("3")); }
    void saveVolumes4() { saveVolumes(QString("4")); }
-;
 };
 
 #endif // KMIX_H
