@@ -135,14 +135,11 @@ void MixDevice::init(  Mixer* mixer, const QString& id, const QString& name, con
         kError(67100) << "MixDevice::setId(\"" << id << "\") . Invalid key - it must not contain spaces" << endl;
         _id.replace(' ', '_');
     }
-    kDebug(67100) << "MixDevice::init() _id=" << _id;
+//    kDebug(67100) << "MixDevice::init() _id=" << _id;
 }
 
 shared_ptr<MixDevice> MixDevice::addToPool()
 {
-    const QString& fullyQualifiedId = getFullyQualifiedId();
-    kDebug() << "MixDevice::init() id=" << fullyQualifiedId;
-
     shared_ptr<MixDevice> thisSharedPtr(this);
     //shared_ptr<MixDevice> thisSharedPtr = ControlPool::instance()->add(fullyQualifiedId, this);
     _dbusControlWrapper = new DBusControlWrapper( thisSharedPtr, dbusPath() );
@@ -150,6 +147,18 @@ shared_ptr<MixDevice> MixDevice::addToPool()
 }
 
 
+/**
+ * Returns the name of the config group
+ * @param Prefix of the group, e.g. "View_ALSA_USB_01"
+ * @returns The config group name in the format "prefix.mixerId,controlId"
+ */
+QString MixDevice::configGroupName(QString prefix)
+{
+         QString devgrp = QString("%1.%2.%3").arg(prefix).arg(mixer()->id()).arg(id());
+	 return devgrp;
+}
+
+
 QString MixDevice::getFullyQualifiedId()
 {
 	QString fqId = QString("%1@%2").arg(_id).arg(_mixer->id());
@@ -161,6 +170,7 @@ void MixDevice::addPlaybackVolume(Volume &playbackVol)
    // Hint: "_playbackVolume" gets COPIED from "playbackVol", because the copy-constructor actually copies the volume levels.
    _playbackVolume = playbackVol;
    _playbackVolume.setSwitchType(Volume::PlaybackSwitch);
+    playbackVol.hasSwitchDisallowRead(); // Only allowed to read once, and only here during migrating the switch back to MixDevice
 }
 
 void MixDevice::addCaptureVolume (Volume &captureVol)
@@ -226,9 +236,18 @@ const QString MixDevice::dbusPath() {
 }
 
 
-bool MixDevice::isMuted()                  { return ( _playbackVolume.hasSwitch() && ! _playbackVolume.isSwitchActivated() ); }
-void MixDevice::setMuted(bool value)       { _playbackVolume.setSwitch( ! value ); }
-void MixDevice::toggleMute()               { setMuted( !isMuted() ); }
+bool MixDevice::isMuted()                  { return ! _playbackVolume.isSwitchActivated(); }
+/**
+ * Returns whether this MixDevice is virtually muted. Only MixDevice objects w/o a physical switch can be muted virtually.
+ */
+bool MixDevice::isVirtuallyMuted()
+{
+	return !hasPhysicalMuteSwitch() && isMuted();
+}
+void MixDevice::setMuted(bool mute)        { _playbackVolume.setSwitch(!mute); }
+void MixDevice::toggleMute()               { setMuted( _playbackVolume.isSwitchActivated()); }
+bool MixDevice::hasMuteSwitch()            { return playbackVolume().hasVolume() || playbackVolume().hasSwitch(); }
+bool MixDevice::hasPhysicalMuteSwitch()    { return playbackVolume().hasSwitch(); }
 bool MixDevice::isRecSource()              { return ( _captureVolume.hasSwitch() &&  _captureVolume.isSwitchActivated() ); }
 bool MixDevice::isNotRecSource()           { return ( _captureVolume.hasSwitch() && !_captureVolume.isSwitchActivated() ); }
 void MixDevice::setRecSource(bool value)   { _captureVolume.setSwitch( value ); }
@@ -343,5 +362,23 @@ QString MixDevice::getVolString(Volume::ChannelID chid, bool capture)
        return volstr;
 }
 
+/**
+ * Returns the playback volume level in percent. If the volume is muted, 0 is returned.
+ * If the given MixDevice contains no playback volume, the capture volume isd used
+ * instead, and 0 is returned if capturing is disabled for the given MixDevice.
+ * 
+ * @returns The volume level in percent
+ */
+int MixDevice::getUserfriendlyVolumeLevel()
+{
+	MixDevice* md = this;
+	bool usePlayback = md->playbackVolume().hasVolume();
+	Volume& vol = usePlayback ? md->playbackVolume() : md->captureVolume();
+	bool isActive = usePlayback ? !md->isMuted() : md->isRecSource();
+	int val = isActive ? vol.getAvgVolumePercent(Volume::MALL) : 0;
+	return val;
+}
+
+
 #include "mixdevice.moc"
 
