@@ -24,20 +24,17 @@
 #define KMIXDOCKWIDGET_H
 
 class QString;
-#include <QWidget>
 class QWidgetAction;
+
+class KToggleAction;
 #include <kstatusnotifieritem.h>
 
 class KMixWindow;
 class Mixer;
+#include "core/mixdevice.h"
 class ViewDockAreaPopup;
 class Volume;
 
-namespace Phonon
-{
-    class MediaObject;
-}
-
 class KMixDockWidget : public KStatusNotifierItem
 {
    Q_OBJECT
@@ -50,46 +47,36 @@ class KMixDockWidget : public KStatusNotifierItem
 
    void setErrorPixmap();
    void ignoreNextEvent();
-   //ViewDockAreaPopup* getDockAreaPopup();
-
- signals:
-   void newMasterSelected();
+   void update();
 
  public slots:
    void setVolumeTip();
    void updatePixmap();
    void activate(const QPoint &pos);
+   void controlsChange(int changeType);
 
  protected:
-   void createMasterVolWidget();
-   void createActions();
-//    void trayToolTipEvent(QHelpEvent *e );
+   void createMenuActions();
    void toggleMinimizeRestore();
 
  private:
-   //ViewDockAreaPopup *_referenceWidget;
+   ViewDockAreaPopup *_referenceWidget2;
    KMenu *_referenceWidget;
    QWidgetAction *_volWA;
-   Phonon::MediaObject *_audioPlayer;
-   bool _playBeepOnVolumeChange;
-   bool _ignoreNextEvent;
    int  _oldToolTipValue;
    char _oldPixmapType;
-   bool _volumePopup;
    KMixWindow* _kmixMainWindow;
-   Mixer *m_mixer;
 
    bool _contextMenuWasOpen;
-
+   bool onlyHaveOneMouseButtonAction();
+   void refreshVolumeLevels();
+   void updateDockMuteAction ( KToggleAction* dockMuteAction );
 
  private slots:
    void dockMute();
    void trayWheelEvent(int delta,Qt::Orientation);
-   //void kmixSystrayAction(QSystemTrayIcon::ActivationReason);
    void selectMaster();
-   void handleNewMaster(QString& soundcard_id, QString& channel_id);
    void contextMenuAboutToShow();
-   void activateMenuOrWindow(bool, const QPoint &);
 };
 
 #endif
